@@ -33,6 +33,14 @@ j_loaded = false;                           % To avoid repeated loading of J
 do_sensor = false;                          % Recalculation of sensor needed
 
 
+%- Limit to set min and max values
+%
+ind    = find( x < R.minmax(:,1) );
+x(ind) = R.minmax(ind,1);
+ind    = find( x > R.minmax(:,2) );
+x(ind) = R.minmax(ind,2);
+  
+
 %- Loop retrieval quantities
 %
 for i = 1 : nq
@@ -61,8 +69,8 @@ for i = 1 : nq
                              qarts_get(fullfile(R.workfolder,'t_field.xml')) );
     elseif strcmp( R.jq{i}.mode, 'logrel' )
       vmr(ig,:,:,:) = getdims( vmr(ig,:,:,:), 2:Q.ATMOSPHERE_DIM+1 ) .* exp(X);
-    else                                                                    %&%
-      assert( false );                                                      %&%
+    else 
+      assert( false );
     end
     %
     clear X
@@ -74,22 +82,49 @@ for i = 1 : nq
     xmlStore( fullfile(R.workfolder,'t_field.xml'), X, 'Tensor3' );
     %
     clear X
+
+   case 'Wind'   %------------------------------------------------------------
+    %
+    X = x2field( Q.ATMOSPHERE_DIM, R.jq{i}.grids, x(ind) );
+    X = arts_regrid( Q.ATMOSPHERE_DIM, R.jq{i}.grids, X, Q );
+    if strcmp( R.jq{i}.subtag, 'u' )
+      xmlStore( fullfile(R.workfolder,'wind_u_field.xml'), X, 'Tensor3' );
+    elseif strcmp( R.jq{i}.subtag, 'v' )
+      xmlStore( fullfile(R.workfolder,'wind_v_field.xml'), X, 'Tensor3' );
+    elseif strcmp( R.jq{i}.subtag, 'w' )
+      xmlStore( fullfile(R.workfolder,'wind_w_field.xml'), X, 'Tensor3' );
+    else
+      assert( false );
+    end
+    %
+    clear X
+    
+   case 'Sensor pointing'   %-------------------------------------------------
+    %
+    assert( strcmp( R.jq{i}.subtag, 'Zenith angle off-set' ) );
+    %
+    sensor_los      = R.los;
+    sensor_los(:,1) = R.los(:,1) + arts_polybasis_func( Q.SENSOR_TIME, ...
+                                                    R.jq{i}.grids{1} )* x(ind); 
+    xmlStore( fullfile(R.workfolder,'sensor_los.xml'), sensor_los, 'Matrix' );
    
    case 'Frequency'   %-------------------------------------------------------
     %
+    assert( length(ind) == 1 );
     if ~do_sensor
       Q.SENSOR_RESPONSE = R.sensor_response;
     end    
     %
     fb = qarts_get(Q.SENSOR_RESPONSE.F_BACKEND);
+    %   
+    if strcmp( R.jq{i}.subtag, 'Shift' )
+      df = x(ind(1));
+    elseif strcmp( R.jq{i}.subtag, 'Stretch' )
+      df = arts_polybasis_func( fb, 1 ) * x(ind(1));
+    else
+      assert( false );
+    end
     %
-    % Shift part
-    df = x(ind(1));
-    %
-    % Stretch part
-    if length( ind ) > 1
-      df = df + x(ind(2)) * arts_polybasis_func( fb, 1 );
-    end     
     Q.SENSOR_RESPONSE.F_BACKEND = fb + df;
     do_sensor                   = true;
     clear   fb;
@@ -102,7 +137,16 @@ for i = 1 : nq
     end
     %
     bl = bl + J(:,ind) * x(ind);
-      
+
+   case 'Sinusoidal baseline fit'   %-----------------------------------------
+    %
+    if ~j_loaded
+      J        = xmlLoad( fullfile( R.workfolder, 'jacobian.xml' ) );
+      j_loaded = 1;
+    end
+    %
+    bl = bl + J(:,ind) * x(ind);
+    
     otherwise   %--------------------------------------------------------------
       error('Unknown retrieval quantitity.'); 
   end 
@@ -118,7 +162,9 @@ end
 
 %- Update sensor characteristics
 %
-arts_sensor( Q, R.workfolder );
+if do_sensor
+  arts_sensor( Q, R.workfolder );
+end
 
 
 %- Total baseline
