@@ -71,8 +71,8 @@ I.ABS_LINESHAPE_FACTOR = [ ...
 Q.ABS_LOOKUP = {};
 I.ABS_LOOKUP = [ ...
 'Has the same functionality as the arts WSV with the same name.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_MODELS = {};
@@ -90,8 +90,8 @@ Q.ABS_NLS = {};
 I.ABS_NLS = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. Can be set by *qarts_abs_species*.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_NLS_PERT = {};
@@ -99,8 +99,8 @@ I.ABS_NLS_PERT = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. See *qarts_set_abs_lookup* for simple setting of ',...
 'this field.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable. Empty ([])signifies no perturbations.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text. Empty ([]) signifies no perturbations.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_P = {};
@@ -108,8 +108,8 @@ I.ABS_P = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. See *qarts_set_abs_lookup* for simple setting of ',...
 'this field.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_SPECIES = {};
@@ -186,8 +186,8 @@ I.ABS_T = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. See *qarts_set_abs_lookup* for simple setting of ',...
 'this field.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_T_PERT = {};
@@ -195,8 +195,8 @@ I.ABS_T_PERT = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. See *qarts_set_abs_lookup* for simple setting of ',...
 'this field.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable. Empty ([]) signifies no perturbations.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_VMRS = {};
@@ -204,8 +204,8 @@ I.ABS_VMRS = [ ...
 'As the arts WSV with the same name. Only needed if an absorption look-up ', ...
 'shall be calculated. See *qarts_set_abs_lookup* for simple setting of ',...
 'this field.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.ABS_WSMS = {};
@@ -282,8 +282,8 @@ I.CLOUDBOX_DO = [ ...
 Q.F_GRID = {};
 I.F_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.FSHIFTFIT = {};
@@ -420,28 +420,30 @@ Q.LAT_GRID = {};
 I.LAT_GRID = [ ...
 'As the arts WSV with the same name. For example, shall be empty for 1D ', ...
 'simulations.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.LAT_TRUE = {};
 I.LAT_TRUE = [ ...
-'As the arts WSV with the same name. Can be given either as the name of ',...
-'a XML file, or as a matching Matlab variable.'
+'As the arts WSV with the same name.',...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.LON_GRID = {};
 I.LON_GRID = [ ...
 'As the arts WSV with the same name. For example, shall be empty for 1D ', ...
 'and 2D simulations.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.LON_TRUE = {};
 I.LON_TRUE = [ ...
-'As the arts WSV with the same name. Can be given either as the name of ',...
-'a XML file, or as a matching Matlab variable.'
+'As the arts WSV with the same name.',...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.L2_EXTRA = {};
@@ -458,8 +460,8 @@ I.L2_EXTRA = [ ...
 Q.MAG_U_FIELD = {};
 I.MAG_U_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.MAG_U = {};
@@ -480,8 +482,8 @@ I.MAG_U = [ ...
 Q.MAG_V_FIELD = {};
 I.MAG_V_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.MAG_V = {};
@@ -493,8 +495,8 @@ I.MAG_V = [ ...
 Q.MAG_W_FIELD = {};
 I.MAG_W_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.MAG_W = {};
@@ -510,16 +512,16 @@ I.MBLOCK_AA_GRID = [ ...
 '#   If the antenna dimension is 1, this variable can be left as {}. ', ...
 'For 2D antennas it has to be set even if the sensor does not include an ', ...
 'antenna.', ...
-'#   Can be given either as the name of a XML file, or as a Matlab',...
-' variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.MBLOCK_ZA_GRID = {};
 I.MBLOCK_ZA_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name. ', ...
 'This has to be set even if the sensor does not include an antenna.', ...
-'#   Can be given either as the name of a XML file, or as a Matlab',...
-' variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.OUTPUT_FILE_FORMAT = {};
@@ -532,8 +534,8 @@ I.OUTPUT_FILE_FORMAT = [ ...
 Q.P_GRID = {};
 I.P_GRID = [ ...
 'Has the same functionality as the arts WSV with the same name.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.POINTING = {};
@@ -592,15 +594,15 @@ I.PPATH_AGENDA = [ ...
 Q.PPATH_LMAX = {};
 I.PPATH_LMAX = [ ...
 'As the arts WSV with the same name .', ...
-'#   Can be given either as the name of a XML file, or as a Matlab',...
-' variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.PPATH_LRAYTRACE = {};
 I.PPATH_LRAYTRACE = [ ...
 'As the arts WSV with the same name .', ...
-'#   Can be given either as the name of a XML file, or as a Matlab',...
-' variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.PPATH_STEP_AGENDA = {};
@@ -685,64 +687,64 @@ Q.SENSOR_RESPONSE_AA = {};
 I.SENSOR_RESPONSE_AA = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_AA_GRID = {};
 I.SENSOR_RESPONSE_AA_GRID = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_F = {};
 I.SENSOR_RESPONSE_F = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_F_GRID = {};
 I.SENSOR_RESPONSE_F_GRID = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_POL = {};
 I.SENSOR_RESPONSE_POL = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a Matlab',...
-' variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_POL_GRID = {};
 I.SENSOR_RESPONSE_POL_GRID = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a Matlab ',...
-'variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_ZA = {};
 I.SENSOR_RESPONSE_ZA = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_RESPONSE_ZA_GRID = {};
 I.SENSOR_RESPONSE_ZA_GRID = [ ...
 'As the arts WSV with the same name. ', ...
 'This field can be ignored, depending on setting of SENSOR_RESPONSE.',...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.SENSOR_TIME = {};
@@ -838,8 +840,8 @@ Q.T_FIELD = {};
 I.T_FIELD = [ ...
 'As the arts WSV with the same name. Will replace temperature data inserted',...
 ' through RAW_ATMOSPHERE.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.TNOISE_C = {};
@@ -853,7 +855,9 @@ I.TNOISE_C = [ ...
 %-----------------------------------------------------------------------------
 Q.TRANSMITTER_POS = {};
 I.TRANSMITTER_POS = [ ...
-'As the arts WSV with the same name.'
+'As the arts WSV with the same name.', ...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.VMR_NEGATIVE_OK = {};
@@ -867,8 +871,8 @@ Q.VMR_FIELD = {};
 I.VMR_FIELD = [ ...
 'As the arts WSV with the same name. Will replace VMR data inserted ',...
 'through RAW_ATMOSPHERE.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.',...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.',...
 '#   For retrievals, the a priori state for *ABS_SPECIES* is determined ',...
 'by this field.'
 ];
@@ -909,8 +913,8 @@ I.WIND_U = [ ...
 Q.WIND_U_FIELD = {};
 I.WIND_U_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.WIND_V = {};
@@ -922,8 +926,8 @@ I.WIND_V = [ ...
 Q.WIND_V_FIELD = {};
 I.WIND_V_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.WIND_W = {};
@@ -935,8 +939,8 @@ I.WIND_W = [ ...
 Q.WIND_W_FIELD = {};
 I.WIND_W_FIELD = [ ...
 'As the arts WSV with the same name. Can be set to [].', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.WSMS_AT_END = {};
@@ -1011,13 +1015,15 @@ Q.Z_FIELD = {};
 I.Z_FIELD = [ ...
 'As the arts WSV with the same name. Will replace altitude data inserted ',...
 'through RAW_ATMOSPHERE.', ...
-'#   Can be given either as the name of a XML file, or as a matching ',...
-'Matlab variable.'
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
 Q.Z_SURFACE = {};
 I.Z_SURFACE = [ ...
 'Surface altitude (above reference ellipsoid). As the arts WSV with the ',...
-'same name.'
+'same name.', ...
+'#   Can be given either as the name of a file, as a matching Matlab ',...
+'variable or control file text.'
 ];
 %-----------------------------------------------------------------------------
