@@ -40,13 +40,14 @@ addpath( fullfile( toppath, 'retrieval','qpack2' ) );
 addpath( fullfile( toppath, 'retrieval' ) ); 
 addpath( fullfile( toppath, 'randomize','iaaft' ) ); 
 addpath( fullfile( toppath, 'randomize' ) ); 
-addpath( fullfile( toppath, 'pyarts' ) ); 
-addpath( fullfile( toppath, 'physics' ) ); 
+addpath( fullfile( toppath, 'physics' ) );
+addpath( fullfile( toppath, 'lineshape', 'faddeeva' ) ); 
 addpath( fullfile( toppath, 'mie' ) ); 
 addpath( fullfile( toppath, 'math' ) ); 
 addpath( fullfile( toppath, 'handy' ) ); 
 addpath( fullfile( toppath, 'h2o', 'parametrisations' ) ); 
 addpath( fullfile( toppath, 'h2o', 'thermodynamics' ) ); 
+addpath( fullfile( toppath, 'gridcreation', 'uniformsphere' ) ); 
 addpath( fullfile( toppath, 'gridcreation', 'annealing' ) ); 
 addpath( fullfile( toppath, 'gridcreation' ) ); 
 addpath( fullfile( toppath, 'graphs' ) );
@@ -65,9 +66,10 @@ addpath( fullfile( toppath, 'covmat' ) );
 addpath( fullfile( toppath, 'collocations' ) ); 
 addpath( fullfile( toppath, 'atmlab' ) ); 
 addpath( fullfile( toppath, 'arts', 'netcdf' ) ); 
-addpath( fullfile( toppath, 'arts', 'scenegen', 'amsu' ) ); 
-addpath( fullfile( toppath, 'arts', 'scenegen' ) ); 
+%addpath( fullfile( toppath, 'arts', 'scenegen', 'amsu' ) ); 
+%addpath( fullfile( toppath, 'arts', 'scenegen' ) ); 
 addpath( fullfile( toppath, 'arts', 'xml' ) ); 
+addpath( fullfile( toppath, 'arts_usage' ) ); 
 addpath( fullfile( toppath, 'arts' ) ); 
 %
 if nversion < 7.04
@@ -84,8 +86,10 @@ else
   atmlab('defaults');  
 end
 
-
+if atmlab('LEGACY_MODE')
+    addpath( fullfile( toppath, 'deprecated' ) ); 
+end
 
 %=== Define some aliases
 %
-alias('amsub', 'mhs');
\ No newline at end of file
+alias('amsub', 'mhs');
