@@ -8,7 +8,7 @@ function varargout = define_datasets(varargin)
 %
 % See also: SatDataset, CollocatedDataset, FieldCopier, Collapser
 
-% $Id: define_datasets.m 8750 2013-12-07 18:14:32Z seliasson $
+% $Id: define_datasets.m 8941 2014-09-15 11:04:40Z olemke $
 % Gerrit Holl
 
 persistent defined;
@@ -1501,9 +1501,11 @@ fields.cpr.RO_ice_water_content_uncertainty.atts.description = ...
 fields.cpr.RO_liq_water_content.type             = 'short';
 fields.cpr.RO_liq_water_content.atts.long_name   = 'liquid water content';
 fields.cpr.RO_liq_water_content.atts.units       = 'g/m^3';
+fields.cpr.RO_liq_water_content.atts.missing_value = -9;
 fields.cpr.RO_liq_water_content_uncertainty.type             = 'short';
 fields.cpr.RO_liq_water_content_uncertainty.atts.long_name   = 'liquid water content uncertainty';
 fields.cpr.RO_liq_water_content_uncertainty.atts.units       = '%';
+fields.cpr.RO_liq_water_content_uncertainty.atts.missing_value = -9;
 fields.cpr.RO_liq_water_content_uncertainty.atts.description = ...
     ['Fractional uncertainty in the RO retrieved LWC (from the liquid-only retrieval), expressed in percent '...
      'and rounded to the nearest integer. A value of 250 indicates an uncertainty >= 250%.'];
@@ -1516,6 +1518,7 @@ fields.cpr.RO_ice_water_path.type    = 'short'; %int16
 fields.cpr.RO_liq_water_path.type    = 'short';
 fields.cpr.RO_liq_water_path.atts.long_name = 'Radar-only liquid water path';
 fields.cpr.RO_liq_water_path.atts.units = 'g/m^2';
+fields.cpr.RO_liq_water_path.atts.missing_value = -9;
 fields.cpr.LO_RO_liquid_water_path.type = 'short';
 fields.cpr.LO_RO_liquid_water_path.atts.long_name = 'Radar-only liquid-only liquid water path';
 fields.cpr.LO_RO_liquid_water_path.atts.units = 'g/m^2';
