@@ -3,6 +3,7 @@
 %    As *qarts_demo*, but with more advanced calculation options.
 %    Pre-calculation of absorption and sensor characteristics is 
 %    exemplified. VMR_FIELD is set through ABS_SPECIES.ATMDATA.
+%    Further, pre-defined agendas are used.
 %
 %    Input temperature data are 2D, and it can not be expected that 
 %    1D results shall be identical to 2D and 3D.
@@ -32,18 +33,17 @@ if isnan( arts_xmldata_path )
   error('You need to ARTS_XMLDATA_PATH to run this example.');
 end
 %
-fascod = fullfile( arts_xmldata_path, 'atmosphere', 'fascod' );
+fascod = fullfile( arts_xmldata_path, 'planets', 'Earth', 'Fascod' );
 
   
 %= Init Q structures
 %
 Q  = qarts;
-
-
-%= Overall settings
 %
-Q.INCLUDES               = { fullfile( 'ARTS_INCLUDES', 'general.arts' ), ...
-                             fullfile( 'ARTS_INCLUDES', 'continua.arts' )};
+Q.INCLUDES              = { fullfile( 'ARTS_INCLUDES', 'general.arts' ), ...
+                            fullfile( 'ARTS_INCLUDES', 'agendas.arts' ), ...
+                            fullfile( 'ARTS_INCLUDES', 'continua.arts' ), ...
+                            fullfile( 'ARTS_INCLUDES', 'planet_earth.arts' ) };
 
 
 %= De-activate parts not used
@@ -52,25 +52,39 @@ Q.CLOUDBOX_DO           = false;
 Q.J_DO                  = false;
 
 
+%= Define agendas
+%
+% Here we do it by using the predefined agenda templates.
+% This works only if the pre-defined agenda is names following the pattern:
+%    name_of_agenda__(Something)
+%
+Q.PPATH_AGENDA               = { 'ppath_agenda__FollowSensorLosPath'   };
+Q.PPATH_STEP_AGENDA          = { 'ppath_step_agenda__GeometricPath'    };
+Q.BLACKBODY_RADIATION_AGENDA = { 'blackbody_radiation_agenda__Planck'  };
+Q.IY_SPACE_AGENDA            = { 'iy_space_agenda__CosmicBackground'   };
+Q.IY_SURFACE_AGENDA          = { 'iy_surface_agenda__UseSurfaceRtprop' };
+Q.IY_MAIN_AGENDA             = { 'iy_main_agenda__Emission'            };
+
+
 %= Atmospheric species
 %
 % Note that ATMDATA for nitrogen is set to a scalar
 %
 Q.ABS_SPECIES(1).TAG{1}  = 'ClO';
-Q.ABS_SPECIES(1).ATMDATA = gf_artsxml( fullfile( fascod, ...
+Q.ABS_SPECIES(1).ATMDATA = gf_artsxml( fullfile( fascod, 'tropical', ...
                             'tropical.ClO.xml' ), 'ClO', 'vmr_field' ); 
 %
 Q.ABS_SPECIES(2).TAG{1}  = 'O3';
-Q.ABS_SPECIES(2).ATMDATA = gf_artsxml( fullfile( fascod, ...
+Q.ABS_SPECIES(2).ATMDATA = gf_artsxml( fullfile( fascod, 'subarctic-summer',...
                               'subarctic-summer.O3.xml' ), 'O3', 'vmr_field' ); 
 %
 Q.ABS_SPECIES(3).TAG{1}  = 'N2O';
-Q.ABS_SPECIES(3).ATMDATA = gf_artsxml( fullfile( fascod, ...
+Q.ABS_SPECIES(3).ATMDATA = gf_artsxml( fullfile( fascod, 'tropical', ...
                             'tropical.N2O.xml' ), 'N2O', 'vmr_field' ); 
 %
 Q.ABS_SPECIES(4).TAG{1}  = 'H2O-*-490e9-510e9'; % Some local lines not in PWR98
 Q.ABS_SPECIES(4).TAG{2}  = 'H2O-PWR98';
-Q.ABS_SPECIES(4).ATMDATA = gf_artsxml( fullfile( fascod, ...
+Q.ABS_SPECIES(4).ATMDATA = gf_artsxml( fullfile( fascod, 'tropical', ...
                             'tropical.H2O.xml' ), 'H2O', 'vmr_field' ); 
 %
 Q.ABS_SPECIES(5).TAG{1}  = 'N2-SelfContStandardType';
@@ -81,7 +95,7 @@ Q.ABS_SPECIES(5).ATMDATA = gf_set( atmdata_empty(0), 0.781, [] );
 %
 Q.T.ATMDATA              = gf_artsxml( fullfile( arts_xmldata_path, ...
          'climatology', 'cira86', 'cira86.t.xml' ), 'Temperature', 't_field' );
-Q.Z_ATMDATA              = gf_artsxml( fullfile( arts_xmldata_path, ...
+Q.Z.ATMDATA              = gf_artsxml( fullfile( arts_xmldata_path, ...
            'climatology', 'cira86', 'cira86.z.xml' ), 'Altitudes', 'z_field' );
 
 
@@ -91,33 +105,36 @@ Q.ATMOSPHERE_DIM         = atmdim;
 %
 Q.P_GRID                 = z2p_simple( [0:500:45e3 46e3:1e3:100e3]' );
 %
-if atmdim < 2
-  Q.LAT_GRID             = 0;          % Only used for interpolation of ATMDATA
+if atmdim == 1
+  Q.LAT_TRUE             = 0;    
+  Q.LON_TRUE             = 80;    
+elseif atmdim == 2
+  Q.LAT_GRID             = [-10:10]'; 
+  Q.LAT_TRUE             = Q.LAT_GRID; 
+  Q.LON_TRUE             = repmat( 0, size( Q.LAT_GRID ) );
 else
-  Q.LAT_GRID             = [-10:10]';  % A true latitude grid
+  Q.LAT_GRID             = [-10:10]'; 
+  Q.LON_GRID             = [-10:10]'; 
 end
 %
+Q.REFELLIPSOID           = ellipsoidmodels( 'SphericalEarth' );
 if atmdim < 3
-  Q.LON_GRID             = 0;          % Only used for interpolation of ATMDATA
+  Q.Z_SURFACE            = repmat( 500, length(Q.LAT_TRUE), length(Q.LON_TRUE));
 else
-  Q.LON_GRID             = [-10:10]';  % A true longitude grid
+  Q.Z_SURFACE            = repmat( 500, length(Q.LAT_GRID), length(Q.LON_GRID));
 end
-%
-Q.R_GEOID                = repmat( constants('EARTH_RADIUS'), ...
-                                      length(Q.LAT_GRID), length(Q.LON_GRID) );
-Q.Z_SURFACE              = repmat( 500, length(Q.LAT_GRID), length(Q.LON_GRID));
-
 
 %= Set-up VMR_FIELD, T_FIELD and Z_FIELD
+% A dummy date
+mjd = date2mjd( 2008, 2, 15 );
 %
 Q.VMR_FIELD              = qarts_vmr_field( Q );
-Q.T_FIELD                = qarts_t_or_z_field( Q, 't', 45 );% Note interp.
-Q.Z_FIELD                = qarts_t_or_z_field( Q, 'z', 45 );% to DOY 45
+Q.T_FIELD                = qarts_atm_field( Q, 't', mjd );
+Q.Z_FIELD                = qarts_atm_field( Q, 'z', mjd );
 
 
 %= Absorption
 %
-%
 Q.F_GRID                 = linspace( 501.18e9, 501.58e9, 201 )';
 Q.STOKES_DIM             = 1;
 %
@@ -152,6 +169,7 @@ else
   %
   Q.ANTENNA_DIM          = 1;
   Q.MBLOCK_ZA_GRID       = [-0.04:0.02:0.04]';
+  H.ANTENNA_DO           = true;
   H.ANTENNA_LOS          = 0;
   H.ANTENNA_RESPONSE     = fullfile( atmlab_example_data, 'antenna.xml' );
   %
@@ -168,14 +186,13 @@ end
 Q.YCALC_WSMS             = { 'yCalc' };
 %
 Q.PPATH_LMAX             = 20e3;
-Q.PPATH_STEP_AGENDA      = { 'ppath_stepGeometric' };
-Q.Y_UNIT                 = 'RJBT';
+Q.IY_UNIT                = 'RJBT';
 %
 zplat                    = 600e3;
-Q.SENSOR_POS             = [ Q.R_GEOID(1,1) + zplat, -23, 0 ];
+Q.SENSOR_POS             = [ zplat, -23, 0 ];
 Q.SENSOR_POS             = Q.SENSOR_POS(1:atmdim);
 %
-Q.SENSOR_LOS             = geomztan2za( Q.R_GEOID(1,1), zplat, ztan );
+Q.SENSOR_LOS             = geomztan2za( Q.REFELLIPSOID(1), zplat, ztan );
 if atmdim == 3
   Q.SENSOR_LOS           = [ Q.SENSOR_LOS, 5 ];
 end
@@ -190,9 +207,9 @@ end
 
 %= Calculate spectrum/spectra
 %
-[y,ydata] = arts_y( Q );
+y = arts_y( Q );
 %
-f = ydata.f;
+f = Q.F_GRID;
 
 
 
