@@ -1,4 +1,4 @@
-% LOADVAR   Loads a specific varaible from a file
+% LOADVAR   Loads a specific variable from a MATLAB data file
 %
 %    The function enables direct loading of a named variable (matlab's load
 %    function puts into a struct). To load the variable x from file data.mat:
@@ -6,7 +6,7 @@
 %        x = loadvar( 'data.mat', 'x' )
 %
 % FORMAT   x = loadvar( filename, varname )
-%        
+%
 % OUT   x          Loaded variable
 % IN    filename   Name of file.
 %       varname    Name of variable.
@@ -15,11 +15,25 @@
 
 
 function x = loadvar( filename, varname )
-  
-X = load( filename, varname );
+
+try
+    X = load( filename, varname );
+catch ME
+    switch ME.identifier
+        case 'MATLAB:load:numColumnsNotSame'
+            % Matlab tried to load as ASCII and failed.
+            % Try to load as binary MAT-file instead.
+            X = load(filename, varname, '-mat');
+        otherwise
+            ME.rethrow();
+    end
+end
 
 if ~isfield( X, varname )
-  error( 'The file does not contain the requested variable.' );
+    error( ['atmlab:' mfilename ':variableNotFound'],...
+        lastwarn);
 else
-  x = getfield( X, varname );
+    x = X.(varname);
+end
+
 end
