@@ -6,7 +6,7 @@ function commands = create_gmt_earth(in)
 % PURPOSE: Create cell strings that will be used in a system call.
 %
 % Created by Salomon Eliasson
-% $Id: create_gmt_earth.m 7228 2011-12-15 20:45:12Z seliasson $
+% $Id: create_gmt_earth.m 8570 2013-08-10 18:36:48Z seliasson $
 
 assert(exist('in','var')==1,'gmtlab:badInput',...
     'This is an internal function to be used by gmt_plot.m')
@@ -16,31 +16,19 @@ in = setup_create_gmt_earth(in);
 F = in.filename;
 
 % Remove earlier .ps and gmt residules
-commands{1} = sprintf('rm -f %s.{ps,eps}',F);
+commands{1} = sprintf('rm -f %s.ps',F);
 %commands{end+1} = sprintf('rm -f .gmtcommands4 .gmtdefaults');
 
 % Set paper size
-commands{end+1} = 'gmtset PAPER_MEDIA a0';
+commands{end+1} = 'gmtset PAPER_MEDIA A0+';
 
 % Annotations of axis
-if isfield(in,'basemap_axis')
-    commands{end+1} = sprintf('gmtset BASEMAP_AXES %s',in.basemap_axis);
-end
-
-% Verticle distance from plot to title
-if isfield(in,'header_offset')
-    commands{end+1} = sprintf('gmtset HEADER_OFFSET %c',in.header_offset);
-end
-
-% Size of title
-if isfield(in,'header_size')
-    commands{end+1} = sprintf('gmtset HEADER_FONT_SIZE %fp',in.header_size);
-end
-
-% Default unit to use
-if isfield(in,'measure_unit')
-    commands{end+1} = sprintf('gmtset MEASURE_UNIT=%s',in.measure_unit);
-end
+commands{end+1} = sprintf('gmtset ANNOT_FONT_SIZE_PRIMARY %s',num2str(in.annot_font_size_primary));
+commands{end+1} = sprintf('gmtset BASEMAP_AXES %s',in.basemap_axis);
+commands{end+1} = sprintf('gmtset HEADER_OFFSET=%s',num2str(in.header_offset));
+commands{end+1} = sprintf('gmtset HEADER_FONT %s',num2str(in.header_font));
+commands{end+1} = sprintf('gmtset HEADER_FONT_SIZE %s',num2str(in.header_fontsize));
+commands{end+1} = sprintf('gmtset MEASURE_UNIT=%s',in.measure_unit);
 
 % other gmtset-commands you might have
 if isfield(in,'gmtset')
@@ -55,6 +43,7 @@ commands{end+1} = in.plot.basemap;
 % NEARNEIGHBOR
 if isfield(in,'nearneighbor') && ~isstruct(in.nearneighbor)
     commands{end+1} = in.nearneighbor;
+    in.grdfile = [in.filename '.grd'];
 elseif ~in.gridded && isfield(in.plot,'grid')
     in.grdfile = [in.filename '.grd'];
     commands{end+1} = nearneighbor(in.grdfile,in.plot.grid);
@@ -73,12 +62,10 @@ if isfield(in,'psscale')
 elseif ~isempty(in.plot.legend)
     commands{end+1} = psscale(F,in.plot.legend);
 end
-
-% NaN LEGEND
-if isfield(in,'psscale_nan')
-    commands{end+1} = in.psscale_nan;
-elseif ~isempty(in.plot.nanlegend)
-    commands{end+1} = in.plot.nanlegend;
+if isfield(in,'psscale_extra')
+    commands{end+1} = in.psscale_extra;
+elseif ~isempty(in.plot.extralegend)
+    commands{end+1} = in.plot.extralegend;
 end
 
 % COASTLINES
@@ -173,7 +160,7 @@ if isfield(in,'pstext') && isstruct(in.pstext)
 end
 
 % LEGEND/S
-[in.plot.legend,in.plot.nanlegend] = mklegend(in);
+[in.plot.legend,in.plot.extralegend] = mklegend(in);
 
 % Close file with this
 in.plot.lastbasemap = last_psbasemap(in);
@@ -188,14 +175,14 @@ if isempty(in.center) || ~strcmp(in.plot.region(1:9),'-180/180/')
 else C = in.center;
 end
 
-proj = sprintf('%s%f/%fi',in.projection,C,in.map_width);
+proj = sprintf('%s%g/%s',in.projection,C,num2str(in.map_width));
 
 function basemap = setupbasemap(in)
 %% setupbasemap
 
-if ~isempty(in.title)
-    basemap = sprintf('psbasemap -R%s -J%s %s -G -P -K -B:."%s": > %s.ps',...
-        in.plot.region,in.plot.proj,in.plotPlacement,gmt_unicode_converter(in.title),in.filename);
+if ~isempty(in.header)
+    basemap = sprintf('psbasemap -R%s -J%s %s -G -P -K --COLOR_FOREGROUND=%s --COLOR_BACKGROUND=%s -B:."%s": > %s.ps',...
+        in.plot.region,in.plot.proj,in.plotPlacement,in.color_foreground,in.color_background,gmt_unicode_converter(in.header),in.filename);
     
 else
     basemap = sprintf('psbasemap -R%s -J%s %s -G -P -K > %s.ps',...
@@ -214,20 +201,32 @@ end
 a.ungriddedfile = in.ungriddedfile;
 a.plotPlacement = in.plotPlacement;
 
-% get resolution of data to pick a good search radius (not used if given)
+% ----------------------
+% AREA
+
 % get number of 1deg boxes in region
 x            = sscanf(in.region,'%f/%f/%f/%f');
 oneDegRegion = ( x(2)-x(1) )*( x(4)-x(3) );
 
-% find the approx density of points
-res = max([ mean(diff(unique(in.lat)));mean(diff(unique(in.lon)))]) ;
 
-% How much RAM is available?
-memGB = freeRAM()/1024;
+% ---------------------
+% Maximum resolution
 
-% What it translates to in terms of resolution:
-maxres = 3 * sqrt((1/memGB) * oneDegRegion * 8 /1024^3); %4bytes double
+% memGB = freeRAM()/1024; % How much RAM is available? TO LARGE
+% some reasonable maximum default
+% apparently it costs 1200bytes per point
 
+memGB = .1;
+maxpoints = memGB*1024^3  / 1200;
+maxres = oneDegRegion/maxpoints;
+
+% -----------------------------------------------------
+% Resolution inferred by data, or by user defined
+
+%data
+res = max([ abs(median(diff(in.lat)));abs(median(diff(in.lon)))]) ;
+
+%user
 if isfield(in,'nearneighbor') &&...
         isstruct(in.nearneighbor) &&...
         isfield(in.nearneighbor,'resolution')
@@ -236,17 +235,17 @@ end
 
 % check if res is acceptable
 if res < maxres
-    logtext(1,['Automatically picked the maximum resolution of:',...
+    logtext(atmlab('OUT'), ['Automatically picked the maximum resolution of: ',...
         '%.4fdeg instead of %.4fdeg defined by measurement density\n'],maxres,res)
     res = maxres;
 else
-    logtext(1,'Plot resolution: %.4f Deg\n',res)
+    logtext(atmlab('OUT'), 'Plot resolution: %.4f Deg\n',res)
 end
 a.increment = sprintf('%fm',60*res); % 60min x resolution
 
 % use increment to decide the search radius, unless given
 if ~isfield(in,'nearneighbor') || ~isfield(in.nearneighbor,'search')
-    a.search = sprintf('%fm', 1.5*( str2double(a.increment(1:end-1)) ));
+    a.search = sprintf('%fm', 1.25*str2double(a.increment(1:end-1)));
 else
     a.search = in.nearneighbor.search;
 end
@@ -269,7 +268,11 @@ end
 if isfield(in,'tickval')
     % make temporary tickval file
     fid=fopen('tickvalues.txt','w');
-    fprintf(fid,sprintf('%s\n',getAnnotFormat(in.tickval)),in.tickval);
+    if isfield(in,'tick_annotation_format')
+        fprintf(fid,in.tick_annotation_format,in.tickval);
+    else
+        fprintf(fid,sprintf('%s\n',getAnnotFormat(in.tickval)),in.tickval);
+    end
     fclose(fid);
 end
 
@@ -283,8 +286,13 @@ switch in.ctable
         a.cptfile = makepolar(tickval,in);
     case 'colorrange'
         % make ctable to be input to makecpt -C%s
-        cpt_from_colorrange(in.colorrange);
-        a.cptfile = makecpt(in);
+        if isfield(in.colorrange,'colors')
+            cpt_from_colorrange(in.colorrange);
+            a.cptfile = makecpt(in);
+        elseif isfield(in.colorrange,'discrete_colors')
+            a.cptfile = cpt_discrete_colors(in);
+        end
+        
     otherwise
         logtext(1,'Processing makecpt\n')
         if ~isfield(in,'makecpt')
@@ -297,8 +305,8 @@ switch in.ctable
 end
 
 % extra legend box for missing values
-if in.nanlegend
-    a.cptnan = xtra_nan_legend(in);
+if isfield(in,'extra_legend')
+    a.cptextra = extra_legend(in);
 end
 
 function a = mkcoast(in)
@@ -360,60 +368,56 @@ default.fontnum = 1;       % sets the font type
 default.justify = 6;       % sets the alignment
 default.color   = '0/0/0'; % textcolor (black)
 for i = 1:length(in)
-   out(i) = optargs_struct(in(i),default);
+    out(i) = optargs_struct(in(i),default);
 end
 
 function [a,b] = mklegend(in)
 %% mklegend
 
 if isfield(in,'fieldname') && isstruct(in.legend) %if not field then nodata.
-    % get what is already in the in-structure
-    F = {'xunit','unit','cptfile'};
+    a = in.legend;
+    % get what is in the in-structure, i.e one level up from in.legend
+    % structure where they really belong
+    F = {'xunit','unit','cptfile','plotPlacement'};
     for f = F(ismember(F,fieldnames(in)))
-        if any(strcmp(f{1},{'unit','xunit'}))
-            a.(f{1}) = gmt_unicode_converter(in.(f{1}));
+        switch f{1}
+            case {'unit','xunit'}
+                a.(f{1}) = gmt_unicode_converter(in.(f{1}));
+            otherwise
+                a.(f{1}) = in.(f{1});
+        end
+    end
+    % Also needed
+    a.cptfile = in.plot.color.cptfile;
+    if isfield(in,'extra_legend') && isstruct(in.extra_legend)
+        if ~isfield(in.extra_legend,'position')
+            [w,wu]=separate_integer_and_unit(in.legend.width); %thickness of legend bar
+            [x,xu]=separate_integer_and_unit(in.legend.xpos);
+            [y,yu]=separate_integer_and_unit(in.legend.ypos);
+            [l,~]=separate_integer_and_unit(in.legend.length);
+            if ~isequal(wu,xu,yu),warning(['atmlab:' mfilename],'miss-matching units will cause strange default placements of extra_legend');end
+            if strcmp(in.legend.orientation,'v')
+                vec = [x, y-0.5*l-2*w, w, w];
+                lsize = sprintf('%g%s/%g%s/%g%s/%g%s',...
+                    vec(1),xu,vec(2),wu,vec(3),wu,vec(3),wu);
+            elseif strcmp(in.legend.orientation,'h')
+                vec = [x+0.5*l+2*w, y, w, w];
+                lsize = sprintf('%g%s/%g%s/%g%s/%g%s',...
+                    vec(1),wu,vec(2),yu,vec(3),wu,vec(3),wu);
+            end
         else
-            a.(f{1}) = in.(f{1});
+            lsize = in.extra_legend.position;
         end
-    end
-    a.plotPlacement = in.plotPlacement;
-    
-    % A little extra legend showig colors of NaNs
-    if in.nanlegend
-        if ~isfield(in.legend,'position_nan')
-            nandef = {[str2double(in.legend.xpos(1:end-1)),...
-                -.2, .2, .2],...
-                [.4, str2double(in.legend.ypos(1:end-1)), .2, .2]};
-            tmp = sprintf('%.2fi/',nandef{1}*in.map_width/9); nsz{1} = tmp(1:end-1);
-            tmp = sprintf('%.2fi/',nandef{2}*in.map_width/9); nsz{2} = [tmp(1:end-1) 'h'];
-            lsize = nsz{ strcmp(in.legend.orientation,'h') +1 };
-        else
-            lsize = in.legend.position_nan;
+        if isfield(in.extra_legend,'fontsize')
+            fz = in.extra_legend.fontsize;
+        else fz = in.annot_font_size_primary;
         end
-        b = sprintf('psscale -D%s -Li -Ccolor_nan.cpt -O -K >> %s.ps',...
-            lsize,in.filename);
+        b = sprintf('psscale -D%s -Xa5 -Ya5 -Li -O -K -C%s --ANNOT_FONT_SIZE_PRIMARY=%s >> %s.ps',...
+            lsize,in.plot.color.cptextra,fz,in.filename);
     end
-    
-    % get xtra options
-    fields ={'annot_font_size_primary','box_spacing','equalboxwidth','length',...
-        'orientation','position','shift_tick_annotations','sidebar',...
-        'tick_annotations','tick_annotation_format','tick_centering','tick_length',...
-        'tick_spacing','width','xpos','ypos'};
-    
-    for F = fields
-        if isfield(in.legend,F{1})
-            a.(F{1}) = in.legend.(F{1});
-        end
-    end
-    
     if isfield(in.legend,'tick_annotations')
         append_tickannotations(in.plot.color.cptfile,in.legend.tick_annotations);
     end
-    
-    % fixed vaules
-    a.cptfile = in.plot.color.cptfile;
-    a.sidebar = in.legend.sidebar;
-    
 end
 if ~exist('b','var'), b = struct([]);end
 if ~exist('a','var'), a = struct([]);end
@@ -430,19 +434,19 @@ tickval = minn:in.stepsize:maxx;
 function out = setup_psboxpoly(in, field)
 %% ps box
 
-l = size(in.(field),1);
+el = size(in.(field),1);
 if isfield(in,[field 'color'])
-    if length(in.([field 'color']))~=l
-        error('Need same number of colors as boxes')
+    if length(in.([field 'color']))~=el
+        error(['atmlab:' mfilename],'Need same number of colors as boxes')
     end
 else in.([field 'color'])(1:l) = {'k'}; %default is black
 end
 
 if isfield(in,([field 'thick']))
-    if length(in.([field 'thick']))~=l
-        error('Need same number of sizes as boxes')
+    if length(in.([field 'thick']))~=el
+        error(['atmlab:' mfilename],'Need same number of sizes as boxes')
     end
-else out.thick(1:l)={10}; %default size=10
+else out.thick(1:el)={10}; %default size=10
 end
 c = list_colors('colors',in.([field 'color']));
 colors = cell(length(c),1);
@@ -475,9 +479,9 @@ step = [60 40 30 20 10 5 2.5];
 b = step(~(bs>lat));
 if isempty(b), b = lat/3; end
 
-default.ticks = sprintf('%.2fg%.2f/%.2fg%.2f',a(1),b(1),a(1)/2,b(1)/2);
+default.ticks = sprintf('%gg%g/%gg%g',a(1),b(1),a(1)/2,b(1)/2);
 in = optargs_struct(in,default);
 
 basemap = sprintf('psbasemap -B%s',in.ticks);
 
-basemap = sprintf('%s -R -J %s -O >> %s.ps',basemap,in.plotPlacement,in.filename);
\ No newline at end of file
+basemap = sprintf('%s -R -J %s -O >> %s.ps',basemap,in.plotPlacement,in.filename);
