@@ -9,7 +9,7 @@ function command = grdcontour(file,in)
 % OUT   command   %s              string command to be used in system call
 %
 % Created by Salomon Eliasson
-% $Id: grdcontour.m 7157 2011-09-18 10:38:57Z seliasson $
+% $Id: grdcontour.m 8362 2013-04-20 18:30:35Z seliasson $
 
 %location of file, region and projection
 grdcontour = sprintf('grdcontour %s -R -J',in.grdfile);
@@ -17,15 +17,15 @@ grdcontour = sprintf('grdcontour %s -R -J',in.grdfile);
 grdcontour = sprintf('%s %s',grdcontour,in.plotPlacement);
 
 if isfield(in,'spacing')
-    grdcontour = sprintf('%s -A%f',grdcontour,in.spacing);
+    grdcontour = sprintf('%s -A%g',grdcontour,in.spacing);
 end
 
 if isfield(in,'fontsize')
-    grdcontour = sprintf('%s+s%f',grdcontour,in.fontsize);
+    grdcontour = sprintf('%s+s%g',grdcontour,num2str(in.fontsize));
 end
 
 if isfield(in,'range')
-    grdcontour = sprintf('%s -L%f-%f',grdcontour,in.range(1),in.range(2));
+    grdcontour = sprintf('%s -L%g-%g',grdcontour,in.range(1),in.range(2));
 end
 
 if isfield(in,'label_placement')
