@@ -19,7 +19,7 @@ function filecpt = makepolar(tickval,in)
 %             and the grandient is equal on both sides of the reference. 
 %
 % Created by Salomon Eliasson
-% $Id: makepolar.m 7221 2011-11-24 18:15:58Z seliasson $
+% $Id: makepolar.m 8744 2013-11-27 07:14:23Z seliasson $
 
 % string format to file 
 diff = tickval(2)-tickval(1);
@@ -29,7 +29,7 @@ while x < 0
     b = b+1;
     x = x*10^b;
 end
-prtstr=sprintf('%%.%df',b);
+prtstr=sprintf('%%g',b);
 strtot = strcat(prtstr,'\t','%3.0f','\t','%3.0f','\t','%3.0f','\t',...
     prtstr,'\t','%3.0f','\t','%3.0f','\t','%3.0f','\n');
 
@@ -146,6 +146,10 @@ if ismember(ref,tickval) && mod(nw,2)
 end
 
 % ADJUST nwhite if ref is inbetween contour lines
+if ref < tickval(1) || ref > tickval(end)
+    error(['gmtlab:' mfilename ':badInput'],'Reference value is outside the range of tick values')
+end
+
 if ~ismember(ref,tickval) && ~mod(nw,2) 
     % if ref is in between the edges and nwhite is even, decrease by 1
     nw = nw-1;
@@ -167,11 +171,24 @@ TT = sum(tickval > ref ) -whitedomain;
 BT = BT*(BT>=0);
 TT = TT*(TT>=0);
 
-% if reference is on the EDGE
+% if reference is close to an EDGE
 if BT < whitedomain || TT < whitedomain
-    if BT < whitedomain, nw = whitedomain-BT; end
-    if TT < whitedomain, nw = whitedomain-TT; end
-    %nw = nw - mod(nw,2); %not sure why this is here
+    if BT < whitedomain
+        nw = nw - (whitedomain-BT);
+        TT = TT + (whitedomain-BT);
+    end
+    if TT < whitedomain
+        nw = nw - (whitedomain-TT);
+        BT = BT + (whitedomain-TT);
+        
+    end
+
+end
+if TT==0
+    BT = BT-1;
+end
+if BT==0
+    TT = TT-1;
 end
 %special 
 assert(BT+TT+nw == length(tickval)-1,['gmtlab:' mfilename ':Bug'],...
