@@ -98,7 +98,7 @@ I.TNOISE = [ ...
 %-----------------------------------------------------------------------------
 Q.Y = {};
 I.Y = [ ...
-'The spectrum.'
+'The spectrum. If multiple spectra, all data appended into a column vector.'
 ];
 %-----------------------------------------------------------------------------
 Q.YEAR = {};
@@ -112,9 +112,9 @@ Q.ZA = {};
 I.ZA = [ ...
 'Line-of-sight zenith angle for the measurement. A scalar value, or a ',...
 'vector. The fields *Z_PLATFORM* and *ZA*, as well as *AA* for 3D case, ',...
-'must have the same size. IF these fields have a length > 1, the ',...
+'must have the same size. If these fields have a length > 1, the ',...
 'measurement will consist of several spectra (having same *LAT* and *LON). ',...
-'IN ARTS, these spectra are simulated as seperate measurement blocks. ',...
+'In ARTS, these spectra are simulated as seperate measurement blocks. ',...
 'Further, *TNOISE* must have a matching size, where the numbers of columns ',...
 'shall match length of *ZA*.'
 ];
