@@ -19,13 +19,22 @@ function [year, month, day, hour, minute, second] = unixsecs2date(secs)
 %   fractional seconds are allowed.
 %
 %   See also DATE2UNIXSECS.
+%   $Id: unixsecs2date.m 8345 2013-04-17 18:16:40Z gerrit $
 
 %   Author:      Peter J. Acklam
 %   Time-stamp:  2003-01-14 21:32:11 +0100
 %   E-mail:      pjacklam@online.no
 %   URL:         http://home.online.no/~pjacklam
 
-   error(nargchk(1, 1, nargin));
+   narginchk(1, 1);
 
-   [year, month, day, hour, minute, second] ...
-      = jd2date(secs / 86400 + date2jd(1970, 1, 1));
+if isscalar(secs)
+   dv = datevec(addtodate(datenum(1970, 1, 1, 0, 0, 0), secs, 'second'));
+   C = num2cell(dv);
+   [year, month, day, hour, minute, second] = deal(C{:});
+else
+   [year, month, day, hour, minute, second] ... 
+	 	      = jd2date(double(secs) / 86400 + date2jd(1970, 1, 1)); 
+end
+
+end
